# Model-based Trajectory Inference for Single-Cell RNA Sequencing Using Deep Learning with a Mixture Prior


This package provides computational tools to perform trajectory inference on scRNA-seq data with Variational Autoencoders. For more details, please refer to https://github.com/jaydu1/VITAE.

# Project Members
Jin-Hong Du, Ming Gao, and Jingshu Wang

# License
This project is licensed under the terms of the MIT license.